/*
 * Hi-Tech C I2C library for Hobbytronics I2CLCD backpack
 *
 * Copyright (C)2011 HobbyTronics.co.uk 2011
 * Freely distributable.
*/

// Clear the LCD screen
void i2clcd_clear(unsigned char address){
	i2c_Start();      					// send Start
	i2c_Address(address, I2C_WRITE);	// Send  slave address with write operation
	i2c_Write(4);						// clear display command
 	i2c_Stop();			  				// send Stop
	__delay_us(100);						// delay for 20 u-seconds
}

// Write a single character
void i2clcd_write(unsigned char address, unsigned char character)
{
	i2c_Start();      					// send Start
	i2c_Address(address, I2C_WRITE);	// Send  slave address with write operation
	i2c_Write(10);						// write character command
	i2c_Write(character);				// character
 	i2c_Stop();			  				// send Stop
	__delay_us(100);						// delay for 20 u-seconds
}

// Create a character - you can create up to 8 characters which
// are stored in memory locations 0-7
void i2clcd_createchar(unsigned char address, unsigned char location, unsigned char charmap[]) {
	unsigned char i;

	location &= 0x7; 					// we only have 8 locations 0-7
	i2c_Start();      					// send Start
	i2c_Address(address, I2C_WRITE);	// Send  slave address with write operation
	i2c_Write(64);						// create character command
	i2c_Write(location);				// character location
	for (int i=0; i<8; i++) {
		i2c_Write(charmap[i]);
	}
 	i2c_Stop();			  				// send Stop
	__delay_us(100);						// delay for 20 u-seconds	 
}

// Clear a line. If the display type has not been defined
// this will clear 20 characters
void i2clcd_clearline(unsigned char address, unsigned char line){
	i2c_Start();      					// send Start
	i2c_Address(address, I2C_WRITE);	// Send  slave address with write operation
	i2c_Write(3);						// clear line command
	i2c_Write(line);					// lines
 	i2c_Stop();			  				// send Stop
	__delay_us(100);						// delay for 20 u-seconds
}

// Define number of rows/columns on the display
void i2clcd_settype(unsigned char address, unsigned char line, unsigned char col){
	i2c_Start();      					// send Start
	i2c_Address(address, I2C_WRITE);	// Send  slave address with write operation
	i2c_Write(5);						// lcd type command
	i2c_Write(line);					// lines
	i2c_Write(col);						// columns
 	i2c_Stop();			  				// send Stop
	__delay_us(100);						// delay for 20 u-seconds
}

// Backlight
void i2clcd_backlight(unsigned char address, unsigned char brightness)
{
	i2c_Start();      					// send Start
	i2c_Address(address, I2C_WRITE);	// Send  slave address with write operation
	i2c_Write(7);						// write character command
	i2c_Write(brightness);				// character
 	i2c_Stop();			  				// send Stop
	__delay_us(100);						// delay for 20 u-seconds
}

// Position the cursor
void i2clcd_setcursor(unsigned char address, unsigned char line, unsigned char col){
	i2c_Start();      					// send Start
	i2c_Address(address, I2C_WRITE);	// Send  slave address with write operation
	i2c_Write(2);						// cursor position command
	i2c_Write(line);					// line
	i2c_Write(col);						// col
 	i2c_Stop();			  				// send Stop
	__delay_us(100);						// delay for 20 u-seconds
}

// Print a string
void i2clcd_print(unsigned char address, char *pstring){
    unsigned char i=0;
	i2c_Start();      					// send Start
	i2c_Address(address, I2C_WRITE);	// Send  slave address with write operation
	i2c_Write(1);						// print string command
    do{ 
        i2c_Write(pstring[i]);
        i++;
    } while(pstring[i]); 
 	i2c_Stop();			  				// send Stop
	__delay_us(100);						// delay for 20 u-seconds
}

// Issue a command to the LCD - refer to HD44780 specification
void i2clcd_command(unsigned char address, unsigned char command){
	i2c_Start();      					// send Start
	i2c_Address(address, I2C_WRITE);	// Send  slave address with write operation
	i2c_Write(6);						// send HT44780 command
	i2c_Write(command);					// line
 	i2c_Stop();			  				// send Stop
	__delay_us(100);						// delay for 20 u-seconds 
}
