/*
 * Hi-Tech C Demo program for 12F1822 communication with Hobbytronics I2CLCD backpack
 *
 * Copyright (C)2011 HobbyTronics.co.uk
 * Freely distributable.
*/

#include <htc.h>
#include <stdio.h>

// Config MCLR Disabled, Code Protect on, Watchdog disabled, Brownout off, Internal Osc
__CONFIG(MCLRE_OFF & CP_ON & WDTE_OFF & BOREN_OFF & FOSC_INTOSC);

#define _XTAL_FREQ 16000000			// Used in __delay_ms() functions
#define I2C_SLAVE 58				// Slave device I2C address

#include "i2c.h"
#include "i2clcd.h"

// We can create up to 8 of our own characters to display
// Here we define 2 characters to be uploaded
unsigned char ht_logo[8] = {
  0b10100,
  0b10100,
  0b11111,
  0b10110,
  0b10110,
  0b00010,
  0b00010,
};
unsigned char smiley[8] = {
  0b00000,
  0b10001,
  0b00000,
  0b00000,
  0b10001,
  0b01110,
  0b00000,
};

unsigned char vstr[40];
unsigned int counter=0;

void main(void)
{

	OSCCON = 0b01111010;	// set internal osc to 16MHz
	TRISA = 0b000000;		//
	PORTA = 0b000000;

	i2c_Init();				// Start I2C as Master 100KHz

	__delay_ms(200);		// delay for 200 milliseconds

	i2clcd_settype(I2C_SLAVE,4,16);				// set lcd rows, cols
	i2clcd_backlight(I2C_SLAVE,100);			// set backlight
    i2clcd_createchar(I2C_SLAVE,0, ht_logo); 	// Upload ht_logo as character 0
    i2clcd_createchar(I2C_SLAVE,1, smiley);		// Upload smiley as character 1
    i2clcd_clear(I2C_SLAVE);					// Clear LCD
    // Display String
    i2clcd_write(I2C_SLAVE,0);                // Display our ht_logo character
    i2clcd_print(I2C_SLAVE,(char*)" HobbyTronics ");
    i2clcd_write(I2C_SLAVE,1);                // Display our smiley character

	while(1){
		__delay_ms(1000);		// delay for 1 seconds
      	i2clcd_setcursor(I2C_SLAVE,4,1);
  		sprintf(vstr, "%d", counter);  
		i2clcd_print(I2C_SLAVE,vstr);		// print counter
		counter++;
	}
}
